Module: Kreuzberg::ElementType

Defined in:
lib/kreuzberg/types.rb

Overview

Semantic element type classification.

Categorizes text content into semantic units for downstream processing. Supports the element types commonly found in Unstructured documents.

Examples:

type = Kreuzberg::ElementType::TITLE
Kreuzberg::ElementType.values # => ["title", "narrative_text", ...]

Constant Summary collapse

TITLE =
'title'
NARRATIVE_TEXT =
'narrative_text'
HEADING =
'heading'
LIST_ITEM =
'list_item'
TABLE =
'table'
IMAGE =
'image'
PAGE_BREAK =
'page_break'
CODE_BLOCK =
'code_block'
BLOCK_QUOTE =
'block_quote'
'footer'
HEADER =
'header'

Class Method Summary collapse

Class Method Details

.valuesObject



28
29
30
# File 'lib/kreuzberg/types.rb', line 28

def self.values
  [TITLE, NARRATIVE_TEXT, HEADING, LIST_ITEM, TABLE, IMAGE, PAGE_BREAK, CODE_BLOCK, BLOCK_QUOTE, FOOTER, HEADER]
end